/* Beispiel fuer Java-Datenstrukturen
 * "Katalog" zur Vorlesung "Softwaretechnologie".
 * (c) Heinrich Hussmann, Uwe Aßmann, TU Dresden, 2013 

 * Diese Version des Beispiels "Katalog" verwendet HashMap<String,Artikel>.
 * @Version 2.0 Generics
 */



import java.util.Map;
import java.util.Set;
import java.util.HashMap;
import java.util.Iterator;

class Artikel {

    private String name;
    private int preis;
  
    public Artikel (String name, int preis) {
	this.name = name;
	this.preis = preis;
    }
  
    public int preis() {
	return preis;
    }
  
    public String toString() {
	return name+"("+preis+")";
    }
}


class Katalog {

    private String name;
    private Map<String,Artikel> inhalt;
    
    public Katalog (String name) {
	this.name = name;
	this.inhalt = new HashMap<String,Artikel>();
    }
        
    public void put (String code, Artikel a) {
	inhalt.put(code,a);
    }
  
    public int anzahl() {
	return inhalt.size();
    }
  
    public Artikel get (String code) {
	return inhalt.get(code);
    }
  
    public String toString() {
	String s = "Katalog "+name+"\n";
	/* Eine Map hat ein KeySet */
	Set<String> keys = inhalt.keySet();
	Iterator<String> it = keys.iterator();
	while (it.hasNext()) {
	    String code = it.next();
	    /* Zugriff auf die Map über den Schlüssel code */
	    s += " "+code+" -> "+inhalt.get(code)+"\n";
	};
	s += "\nAnzahl Artikel in Katalog: "+inhalt.size()+"\n";
	return s;
    }
  
  
    public static void main (String[] args) {
      
	Artikel tisch = new Artikel("Tisch",200);
	Artikel stuhl = new Artikel("Stuhl",100);
	Artikel schrank = new Artikel("Schrank",300);
	Artikel regal = new Artikel("Regal",200);
 
	Katalog k = new Katalog("Katalog1");
	k.put("M01",tisch);
	k.put("M02",stuhl);
	k.put("M03",schrank);
	System.out.println(k);
    
	/* Ersetze den Schrank im Sortiment */
	k.put("M03",regal);
	System.out.println(k);
    }
  
}
